Index: src/heap/heap.cc |
diff --git a/src/heap/heap.cc b/src/heap/heap.cc |
index 3b5ee6e81b30516d5a29812269f8bb76a4ef3e45..0598afa94c5990d480aa5423101c1629f461293d 100644 |
--- a/src/heap/heap.cc |
+++ b/src/heap/heap.cc |
@@ -3574,11 +3574,12 @@ AllocationResult Heap::CopyJSObject(JSObject* source, AllocationSite* site) { |
// Make the clone. |
Map* map = source->map(); |
// We can only clone regexps, normal objects or arrays. Copying anything else |
// will break invariants. |
CHECK(map->instance_type() == JS_REGEXP_TYPE || |
map->instance_type() == JS_OBJECT_TYPE || |
- map->instance_type() == JS_ARRAY_TYPE); |
+ map->instance_type() == JS_ARRAY_TYPE || |
+ map->instance_type() == JS_SPECIAL_API_OBJECT_TYPE); |
int object_size = map->instance_size(); |
HeapObject* clone = nullptr; |
@@ -3574,11 +3574,12 @@ AllocationResult Heap::CopyJSObject(JSObject* source, AllocationSite* site) { |
// Make the clone. |
Map* map = source->map(); |
- // We can only clone regexps, normal objects or arrays. Copying anything else |
- // will break invariants. |
+ // We can only clone regexps, normal objects, api objects or arrays. Copying |
+ // anything else will break invariants. |
CHECK(map->instance_type() == JS_REGEXP_TYPE || |
map->instance_type() == JS_OBJECT_TYPE || |